@@ -159,6 +159,9 @@ static int tdp_max_x6ar5xx[] = { 0xd2, 0xd2, 0x1a4 };
 static int tdp_min_x6fr5xx[] = { 0x19, 0x19, 0x19 };
 static int tdp_max_x6fr5xx[] = { 0xa2, 0xa2, 0xc3 };
 
+static int tdp_min_xxxx45xs[] = { 0x0a, 0x0a, 0x0a };
+static int tdp_max_xxxx45xs[] = { 0x64, 0x64, 0x69 };
+
 static int *tdp_min_defs = NULL;
 static int *tdp_max_defs = NULL;
 
@@ -242,6 +245,9 @@ static void uw_id_tdp(void)
 	} else if (dmi_match(DMI_PRODUCT_SKU, "STELLARIS16A07")) {
 		tdp_min_defs = tdp_min_x6fr5xx;
 		tdp_max_defs = tdp_max_x6fr5xx;
+	} else if (dmi_match(DMI_BOARD_NAME, "X5KK45xS_X5SP45xS")) {
+		tdp_min_defs = tdp_min_xxxx45xs;
+		tdp_max_defs = tdp_max_xxxx45xs;
 #endif
 	} else {
 		tdp_min_defs = NULL;
