@@ -940,6 +940,7 @@ static int is_auto_boot_and_powershare_supported(bool *status)
 		  // IBP Gen10
 		  dmi_match(DMI_BOARD_NAME, "XxHP4NAx") ||
 		  dmi_match(DMI_BOARD_NAME, "XxKK4NAx_XxSP4NAx") ||
+		  dmi_match(DMI_BOARD_NAME, "XxAR4NAx") ||
 
 		  // Stellaris Gen6
 		  dmi_match(DMI_BOARD_NAME, "GM6IXxB_MB1") ||
@@ -952,7 +953,10 @@ static int is_auto_boot_and_powershare_supported(bool *status)
 
 		  // Stellaris Slim Gen6
 		  dmi_match(DMI_BOARD_NAME, "GMxHGxx") ||
-		  dmi_match(DMI_BOARD_NAME, "GM5IXxA");
+		  dmi_match(DMI_BOARD_NAME, "GM5IXxA") ||
+
+		  // InfinityBook Max Gen10
+		  dmi_match(DMI_BOARD_NAME, "X5KK45xS_X5SP45xS");
 
 	return 0;
 }
@@ -1470,6 +1474,7 @@ struct uniwill_device_features_t *uniwill_get_device_features(void)
 		|| dmi_match(DMI_BOARD_NAME, "GXxHRXx")
 		|| dmi_match(DMI_BOARD_NAME, "XxHP4NAx")
 		|| dmi_match(DMI_BOARD_NAME, "XxKK4NAx_XxSP4NAx")
+		|| dmi_match(DMI_BOARD_NAME, "XxAR4NAx")
 
 		// Note: XMG Fusion removed for now, seem to have
 		// neither same power profile control nor TDP set
@@ -1504,6 +1509,7 @@ struct uniwill_device_features_t *uniwill_get_device_features(void)
 		|| dmi_match(DMI_BOARD_NAME, "GXxHRXx")
 		|| dmi_match(DMI_BOARD_NAME, "XxHP4NAx")
 		|| dmi_match(DMI_BOARD_NAME, "XxKK4NAx_XxSP4NAx")
+		|| dmi_match(DMI_BOARD_NAME, "X5KK45xS_X5SP45xS")
 #endif
 	;
 
